import os
import json
import time
import requests
from typing import Dict, List, Optional, Any, Union
import logging

# 配置日志
logging.basicConfig(
    level=logging.INFO,
    format="%(asctime)s - %(name)s - %(levelname)s - %(message)s"
)
logger = logging.getLogger("TFT-Strategist-DataLoader")

class DataLoader:
    """
    数据加载器，负责从本地文件或在线接口获取云顶之弈的职业、特质和棋子数据
    """
    # 数据源URL
    DATA_URLS = {
        'chess': 'https://game.gtimg.cn/images/lol/act/img/tft/js/chess.js',
        'job': 'https://game.gtimg.cn/images/lol/act/img/tft/js/job.js',
        'race': 'https://game.gtimg.cn/images/lol/act/img/tft/js/race.js'
    }
    
    # 本地数据文件路径
    DATA_FILES = {
        'chess': 'data/chess.json',
        'job': 'data/job.json',
        'race': 'data/race.json'
    }
    
    def __init__(self, use_local_if_exists: bool = True, update_interval: int = 86400):
        """
        初始化数据加载器
        
        Args:
            use_local_if_exists: 是否优先使用本地文件（如果存在且未过期）
            update_interval: 数据更新间隔（秒），默认为24小时
        """
        self.use_local_if_exists = use_local_if_exists
        self.update_interval = update_interval
        self.data_cache = {
            'chess': None,
            'job': None,
            'race': None
        }
        
        # 确保数据目录存在
        os.makedirs('data', exist_ok=True)
    
    def load_all_data(self) -> bool:
        """
        加载所有云顶之弈数据
        
        Returns:
            bool: 加载是否成功
        """
        success = True
        for data_type in self.DATA_URLS.keys():
            if not self.load_data(data_type):
                success = False
        return success
    
    def load_data(self, data_type: str) -> bool:
        """
        加载指定类型的数据
        
        Args:
            data_type: 数据类型，可选值为 'chess', 'job', 'race'
            
        Returns:
            bool: 加载是否成功
        """
        if data_type not in self.DATA_URLS:
            logger.error(f"未知的数据类型: {data_type}")
            return False
            
        # 检查本地文件是否存在且未过期
        local_file = self.DATA_FILES[data_type]
        if self.use_local_if_exists and os.path.exists(local_file):
            # 检查文件修改时间
            file_mtime = os.path.getmtime(local_file)
            if time.time() - file_mtime < self.update_interval:
                try:
                    with open(local_file, 'r', encoding='utf-8') as f:
                        data = json.load(f)
                    self.data_cache[data_type] = data
                    logger.info(f"已从本地文件加载 {data_type} 数据")
                    return True
                except Exception as e:
                    logger.warning(f"从本地加载 {data_type} 数据失败: {e}")
        
        # 从在线接口获取数据
        try:
            logger.info(f"正在从在线接口获取 {data_type} 数据...")
            response = requests.get(self.DATA_URLS[data_type], timeout=10)
            response.raise_for_status()
            
            data = response.json()
            
            # 保存到本地文件
            with open(local_file, 'w', encoding='utf-8') as f:
                json.dump(data, f, ensure_ascii=False, indent=2)
            
            self.data_cache[data_type] = data
            logger.info(f"已从在线接口获取并保存 {data_type} 数据")
            return True
            
        except Exception as e:
            logger.error(f"从在线接口获取 {data_type} 数据失败: {e}")
            return False
    
    def get_data(self, data_type: str) -> Optional[Dict[str, Any]]:
        """
        获取指定类型的数据
        
        Args:
            data_type: 数据类型，可选值为 'chess', 'job', 'race'
            
        Returns:
            Optional[Dict[str, Any]]: 数据字典，加载失败时返回None
        """
        if data_type not in self.DATA_URLS:
            logger.error(f"未知的数据类型: {data_type}")
            return None
            
        # 如果数据尚未加载，则先加载
        if self.data_cache[data_type] is None:
            if not self.load_data(data_type):
                return None
                
        return self.data_cache[data_type]
    
    def reload_data(self, force: bool = False) -> bool:
        """
        重新加载所有数据
        
        Args:
            force: 是否强制从在线接口获取，忽略本地文件
            
        Returns:
            bool: 重新加载是否成功
        """
        prev_use_local = self.use_local_if_exists
        if force:
            self.use_local_if_exists = False
        
        success = self.load_all_data()
        
        # 恢复原来的设置
        self.use_local_if_exists = prev_use_local
        
        return success
    
    def get_latest_version(self) -> Optional[str]:
        """
        获取当前数据的版本号
        
        Returns:
            Optional[str]: 版本号，数据未加载时返回None
        """
        # 优先使用棋子数据的版本，如果没有则尝试其他数据源
        for data_type in ['chess', 'job', 'race']:
            data = self.get_data(data_type)
            if data and 'version' in data:
                return data['version']
        
        return None


if __name__ == "__main__":
    # 测试代码
    loader = DataLoader()
    if loader.load_all_data():
        print(f"数据加载成功，当前版本: {loader.get_latest_version()}")
        print(f"棋子数量: {len(loader.get_data('chess')['data'])}")
        print(f"职业数量: {len(loader.get_data('job')['data'])}")
        print(f"特质数量: {len(loader.get_data('race')['data'])}")
    else:
        print("数据加载失败") 