"""
评分系统演示脚本 - 展示如何使用自定义权重功能
"""
import os
import sys
import logging
from typing import Dict, Any

# 添加项目根目录到Python路径
sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))

from src.data_provider import DataQueryAPI
from src.recommendation import RecommendationEngine, TeamComposition
from src.scoring import TeamScorer, ScoringConfig, ConfigLoader

# 配置日志
logging.basicConfig(
    level=logging.INFO,
    format="%(asctime)s - %(name)s - %(levelname)s - %(message)s"
)
logger = logging.getLogger("TFT-Strategist-Demo")

def print_team_info(team: TeamComposition) -> None:
    """打印阵容信息"""
    print("\n=== 阵容信息 ===")
    print(f"阵容人口: {len(team.chess_list)}")
    print("\n棋子列表:")
    for chess in team.chess_list:
        print(f"  {chess['displayName']} ({chess.get('price', '?')}金)")
    
    print("\n激活的羁绊:")
    if team.synergy_levels.get('job'):
        print("  职业羁绊:")
        for job in team.synergy_levels['job']:
            print(f"    {job['name']}: {job['count']}/{job['level']}")
    
    if team.synergy_levels.get('race'):
        print("  特质羁绊:")
        for race in team.synergy_levels['race']:
            print(f"    {race['name']}: {race['count']}/{race['level']}")


def demo_scoring_with_custom_weights() -> None:
    """演示使用自定义权重进行评分"""
    # 初始化API
    api = DataQueryAPI()
    
    # 创建推荐引擎
    engine = RecommendationEngine(api)
    
    # 1. 使用默认权重评分
    print("\n=== 使用默认权重评分 ===")
    scorer_default = TeamScorer()
    team = engine.recommend_team(population=8)
    score_default = scorer_default.score_team(team)
    print(f"默认权重下的评分: {score_default:.2f}")
    print_team_info(team)
    
    # 2. 使用配置文件中的自定义权重评分
    print("\n=== 使用配置文件中的自定义权重评分 ===")
    scorer_file = TeamScorer(config_path="data/weights_config.yaml")
    score_file = scorer_file.score_team(team)
    print(f"配置文件权重下的评分: {score_file:.2f}")
    print(f"评分差异: {score_file - score_default:.2f}")
    
    # 3. 使用代码中设置的自定义权重评分
    print("\n=== 使用代码中设置的自定义权重评分 ===")
    scorer_code = TeamScorer()
    
    # 设置特定羁绊的权重
    scorer_code.set_synergy_weight("狙神", 2.0)
    scorer_code.set_synergy_weight("刺客", 1.8)
    
    # 设置特定棋子的权重
    scorer_code.set_chess_weight("艾希", 2.0)
    scorer_code.set_chess_weight("薇恩", 1.8)
    
    score_code = scorer_code.score_team(team)
    print(f"代码设置权重下的评分: {score_code:.2f}")
    print(f"评分差异: {score_code - score_default:.2f}")
    
    # 4. 根据特定羁绊推荐阵容
    print("\n=== 根据特定羁绊推荐阵容 ===")
    # 寻找一个包含狙神的阵容
    team_with_sniper = engine.recommend_team(
        population=8, 
        required_synergies={'job': [{'name': '狙神', 'level': 1}]}
    )
    
    # 使用不同的评分器评分
    score_default = scorer_default.score_team(team_with_sniper)
    score_file = scorer_file.score_team(team_with_sniper)
    score_code = scorer_code.score_team(team_with_sniper)
    
    print(f"默认权重下的评分: {score_default:.2f}")
    print(f"配置文件权重下的评分: {score_file:.2f}")
    print(f"代码设置权重下的评分: {score_code:.2f}")
    print_team_info(team_with_sniper)
    
    # 5. 动态修改配置文件并重新加载
    print("\n=== 动态修改配置文件并重新加载 ===")
    config_loader = ConfigLoader("data/weights_config.yaml")
    config_data = config_loader.load_config()
    
    # 修改配置
    if 'synergy_weights' in config_data:
        config_data['synergy_weights']['狙神'] = 2.5
        
    # 保存修改后的配置
    import yaml
    with open("data/weights_config.yaml", 'w', encoding='utf-8') as f:
        yaml.dump(config_data, f, allow_unicode=True, default_flow_style=False)
    
    # 重新加载配置
    scorer_file.reload_config()
    score_reloaded = scorer_file.score_team(team_with_sniper)
    print(f"重新加载配置后的评分: {score_reloaded:.2f}")
    print(f"重新加载前的评分: {score_file:.2f}")
    print(f"评分差异: {score_reloaded - score_file:.2f}")


if __name__ == "__main__":
    demo_scoring_with_custom_weights() 