"""
测试评分系统的配置加载功能
"""
import sys
import os
import logging
from dataclasses import dataclass
from typing import Dict, List, Optional

# 添加项目根目录到Python路径
sys.path.append(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))

from src.scoring.scoring_system import TeamScorer
from src.config import get_global_weights_config

# 配置日志
logging.basicConfig(level=logging.INFO)
logger = logging.getLogger("TFT-Strategist-TestScoring")

@dataclass
class MockTeam:
    """模拟的阵容类，用于测试"""
    chess_list: List[Dict]
    synergy_levels: Dict

def main(config_path: Optional[str] = None):
    """
    主函数
    
    Args:
        config_path: 配置文件路径，用于全局权重配置
    """
    logger.info("开始测试评分系统...")
    
    # 加载全局权重配置
    weights_config = get_global_weights_config(config_path)
    
    # 创建评分器实例
    scorer = TeamScorer(config_path=config_path)
    
    # 打印全局配置
    logger.info("基础权重:")
    base_weights = weights_config.get_base_weights()
    for param, value in base_weights.items():
        logger.info(f"  {param}: {value}")
    
    logger.info("羁绊等级倍数:")
    level_weights = weights_config.get_synergy_level_weights()
    for level, multiplier in sorted(level_weights.items(), key=lambda x: int(x[0])):
        logger.info(f"  等级 {level}: {multiplier}")
    
    logger.info("棋子费用倍数:")
    cost_weights = weights_config.get_cost_weights()
    for cost, multiplier in sorted(cost_weights.items(), key=lambda x: int(x[0])):
        logger.info(f"  费用 {cost}: {multiplier}")
    
    logger.info("羁绊自定义权重 (前5个):")
    synergy_weights = weights_config.get_synergy_weights()
    for name, weight in list(sorted(synergy_weights.items()))[:5]:
        logger.info(f"  {name}: {weight}")
    
    logger.info("棋子自定义权重 (前5个):")
    chess_weights = weights_config.get_chess_weights()
    for name, weight in list(sorted(chess_weights.items()))[:5]:
        logger.info(f"  {name}: {weight}")
    
    # 测试修改权重
    logger.info("\n测试修改权重:")
    test_synergy = next(iter(synergy_weights.keys()))
    original_weight = synergy_weights.get(test_synergy, 1.0)
    new_weight = original_weight + 0.5
    
    logger.info(f"将羁绊 {test_synergy} 的权重从 {original_weight} 修改为 {new_weight}")
    weights_config.set_synergy_weight(test_synergy, new_weight)
    
    # 确认修改生效
    updated_weight = weights_config.get_synergy_weights().get(test_synergy)
    logger.info(f"修改后的权重: {updated_weight}")
    
    # 重新加载评分系统配置
    scorer.reload_config()
    
    # 测试评分函数
    mock_team = MockTeam(
        chess_list=[
            {"displayName": "佛耶戈", "price": "4"},
            {"displayName": "厄加特", "price": "5"},
            {"displayName": "盖伦", "price": "3"},
            {"displayName": "扎克", "price": "3"}
        ],
        synergy_levels={
            "job": [
                {"name": "重装战士", "level": 2, "count": 2},
                {"name": "斗士", "level": 2, "count": 2}
            ],
            "race": [
                {"name": "鳄霸", "level": 1, "count": 1}
            ]
        }
    )
    
    score = scorer.score_team(mock_team)
    logger.info(f"模拟阵容评分: {score}")
    
    # 恢复原来的权重
    logger.info(f"将羁绊 {test_synergy} 的权重恢复为 {original_weight}")
    weights_config.set_synergy_weight(test_synergy, original_weight)
    
    # 重新评分
    scorer.reload_config()
    score = scorer.score_team(mock_team)
    logger.info(f"恢复权重后的评分: {score}")
    
    logger.info("测试完成!")

if __name__ == "__main__":
    main() 